@@ -30,6 +30,7 @@ import gzip
 import os
 import re
 from six.moves.urllib.request import urlretrieve
+from six.moves import urllib_parse
 
 import datetime
 # Constants for directory structure
@@ -79,8 +80,8 @@ class Repository(object):
 
         # URL of the Yum repository and associated files
         self.name = name
-        self.repourl = url
-        self.repomdurl = self.repourl + "/repodata/repomd.xml"
+        self.repourl = url.rstrip("/") + "/"
+        self.repomdurl = urllib_parse.urljoin(self.repourl, "repodata/repomd.xml")
         self.localRepomdXml = os.path.join(repocachedir, "repomd.xml")
 
         # Cache directory and file names
@@ -148,8 +149,9 @@ class Repository(object):
                    ltimestamp is None or
                    timestamp > ltimestamp):
                     # We need to update the DB in this case
-                    furl = self.repourl + "/" + filename
+                    furl = urllib_parse.urljoin(self.repourl, filename)
                     log.info("Updating the RPM database for % s" % ba.__name__)
+                    log.debug("Using URL %s" % furl)
                     self.backend.getLatestDB(furl)
                     # Now saving the metadata to the repomd file
                     with open(self.localRepomdXml, 'wb') as ftmp:
@@ -238,6 +240,7 @@ class Repository(object):
     def _getRemoteMetadata(self):
         """ Gets the remote repomd file """
         log.info("NET - Getting remote metadata for %s" % self.name)
+        log.debug("Using URL %s" % self.repomdurl)
         from six.moves.urllib.request import urlopen
 
         ret = None
