@@ -981,7 +981,7 @@ class Installer(object):
                             shutil.copy(tmp_name, full_filename)
                             break
                     except Exception as e:
-                        self.log.error("Error in downloading file %s with" %
+                        self.log.error("Error in downloading file %s with %s" %
                                        (full_filename, e))
                     finally:
                         if os.path.exists(tmp_name):
