@@ -131,7 +131,7 @@ class LCGYumConsistencyClient(object):
             # is used skipConfig allows returning a config with the LHCb
             # repositories
             from lbinstall.LHCbConfig import Config
-            conf = Config()
+            conf = Config(siteroot)
 
             # Initializing the installer
             self.checker = YumChecker(siteroot=siteroot,
