@@ -538,7 +538,7 @@ class PackageManager(object):
                             fout.write(fin.read())
                         os.chmod(target, attrs["mode"])
                         self.files_to_rollback['files'].append(target)
-                elif not os.path.exists(target) and not overwrite:
+                elif (os.path.exists(target) and not attrs["isDir"]) and not overwrite:
                     self.removeFiles()
                     self.removeBackupFiles()
                     raise Exception("File %s already exists. If you want to"
