@@ -419,6 +419,10 @@ class DBManager:
         session = self._getSession()
         ret = []
         for p in session.query(Provide).filter(Provide.name == reqname).all():
+            if p.version and '-' in p.version:
+                tmp = p.version.split('-')
+                p.version = tmp[0]
+                p.release = tmp[1]
             ret.append(dmProvides(p.name,
                                   p.version,
                                   p.release,
