@@ -33,7 +33,7 @@ class TestRepository(unittest.TestCase):
 
         # Config should be soimplified...
         self.siteroot = mkdtemp("testrepo")
-        config = LHCbConfig.Config()
+        config = LHCbConfig.Config(self.siteroot)
         yumConfig = config.getRepoConfig()
         self.lbYumClient = LbYumClient("",
                                        dict([(k, v["url"]) for k, v in
