@@ -35,7 +35,7 @@ class Test(unittest.TestCase):
         dbpath = "%s/var/lib/db/packages.db" % self.siteroot
         if os.path.exists(dbpath):
             os.unlink(dbpath)
-        config = Config(None, skipConfig=True)
+        config = Config(self.siteroot, None, skipDefaultConfig=True)
         config.repos['lhcbdev'] = {'url': 'http://lhcb-rpm.web.cern.ch/'
                                           'lhcb-rpm/lhcbdevtests'}
         self._mgr = Installer(self.siteroot, config=config)
