@@ -26,12 +26,8 @@ class Test(unittest.TestCase):
             os.makedirs("%s/tmp" % self.siteroot)
         logging.basicConfig()
         if not os.path.exists(self.filename):
-            try:
-                # Python 3 workaround
-                import urllib.request as urllib
-            except:
-                import urllib
-            urllib.urlretrieve(self.url, self.filename)
+            from six.moves.urllib.request import urlretrieve
+            urlretrieve(self.url, self.filename)
 
     def tearDown(self):
         shutil.rmtree(self.siteroot, ignore_errors=True)
